package com.dgtly.wxportal.controller;

import com.dgtly.common.annotation.ApiPassToken;
import com.dgtly.common.core.controller.ApiBaseController;
import com.dgtly.common.core.domain.AjaxResult;
import com.dgtly.common.core.domain.ParameterObject;
import com.dgtly.system.domain.CustomersExt;
import com.dgtly.system.domain.SysUser;
import com.dgtly.system.service.ICustomersExtService;
import com.dgtly.system.service.ISysUserExtService;
import com.dgtly.system.service.ISysUserService;
import com.dgtly.wxportal.config.ESignConfig;
import com.dgtly.wxportal.domain.OrderFile;
import com.dgtly.wxportal.service.*;
import com.dgtly.wxportal.utils.file.fileDownloadUtil;
import com.sun.org.apache.xpath.internal.operations.Bool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * @description:e签宝认证
 * @author:qxm
 * @date:2020/10/12 16:18
 */
@Api(tags = "e签宝相关API", description = "提供e签宝服务API")
@RequestMapping("eSign")
@RestController
@ApiPassToken
public class EsignController extends ApiBaseController {

    @Autowired
    private IEsignPersonRealnVerifyService personRealnVerifyService;
    @Autowired
    private IEsignOrganRealVerifyService organRealVerifyService;
    @Autowired
    private IEsignSignService signService;
    @Autowired
    private IOrderFileService orderFileService;
    @Autowired
    private ISysUserService userService;
    @Autowired
    private ISysUserExtService userExtService;
    @Autowired
    private ICustomersExtService customersExtService;
    @Autowired
    private ESignService eSignService;
    @Autowired
    private ESignConfig eSignConfig;
    /**
     * 经销商订单签收方法
     * 没有注册就注册，注册完就认证，然后再点击签署按钮，获取经销商用户id，对应主体id
     * E签宝一步发起签署
     */
    @ApiOperation(value = "订单签收", notes = "参数：{'orderId':'xxx','userId':'xxx'}" +
            "\n（orderId：订单编号" +
            "\n（userId：用户id")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params", paramType = "body")
    })
    @PostMapping("dealerSign")
    public Object dealerSign() {

        ParameterObject obj = getParameterObject();
        obj.checkParameterNotNull("orderId,userId");
        String orderId = obj.getString("orderId");
        String userId = obj.getString("userId");

        String businessScene = "订单签收";
        String fileName = orderId+"_签收订单.pdf";
        /*根据userId查询个人注册后accountId*/
        String signerAccountId = "";
        SysUser sysUser = userService.selectUserById(Long.parseLong(userId));
        if (sysUser!=null){
            signerAccountId=sysUser.getAccountId();
        }
        /*根据订单id关联查询企业注册后id*/
        String authorizedAccountId =customersExtService.selectOrgIdByOrderId(orderId);
        /* 根据订单id关联查询企业代号*/
        String chainsCode = customersExtService.selectchainsCodeByOrderId(orderId);
        /*首先根据订单id-orderId查询订单是否已被签署*/
        OrderFile orderFlag = orderFileService.selectOrderFileById(orderId);
        if (orderFlag==null) {
            /*1、根据传入订单id，查询订单相关信息生成PDF，调用e签宝上传方法返回文件fileId*/
            String fileId = eSignService.upload(orderId);
            /*2、调用E签宝接口一步发起流程，得到返回的流程id*/
            String flowId = signService.oneStepFlow(businessScene, fileId, fileName, signerAccountId, authorizedAccountId);
            /*3、调用E签宝获取签署地址*/
            String result = signService.processExecuteUrl(flowId, signerAccountId, authorizedAccountId);
            /*4、保存订单id和flowId*/
            OrderFile orderFile = new OrderFile();
            orderFile.setOrderId(orderId);
            orderFile.setChainsCode(chainsCode);
            orderFile.setCustomersCode(authorizedAccountId);
            orderFile.setSignerId(signerAccountId);
            orderFile.setSignerName(sysUser.getUserName());
            orderFile.setFlowId(flowId);
            orderFileService.insertOrderFile(orderFile);
            return result;
        }else{
            return AjaxResult.error("订单已签署");
        }
    }



    /**
     * 经销商通过签署地址签署后，回调此方法，通过flowId得到签署后的文件下载地址并保存url
     */
    @ApiOperation(value = "经销商通过签署地址签署后，回调此方法")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params", paramType = "body")
    })
    @PostMapping("updateOrderFile")
    public Object updateOrderFile() {
        ParameterObject obj = getParameterObject();
        obj.checkParameterNotNull("flowId");
        String flowId = obj.getString("flowId");
        String fileUrl = signService.processDocumentDownload(flowId);

        /*下载保存签署后的文件，返回文件存储地址*/
        OrderFile orderFlag = orderFileService.selectOrderFileByFlowId(flowId);
        fileDownloadUtil.downloadFile(eSignConfig.getFileUrl(),orderFlag.getOrderId()+"_签收订单.pdf",fileUrl);
        OrderFile orderFile = new OrderFile();
        orderFile.setFlowId(flowId);
        orderFile.setFileUrl(eSignConfig.getFileUrl()+orderFlag.getOrderId()+"_签收订单.pdf");
        orderFileService.updateOrderFileByFlowId(orderFile);
        return AjaxResult.success();
    }


    @ApiOperation(value = "E签宝个人认证", notes = "参数：{'userId':'XXXXXXX'}" +
            "\n（userId：待认证用户id）")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params", paramType = "body")
    })
    @PostMapping("personRealnVerify")
    public Object personRealnVerify() {
        ParameterObject obj = getParameterObject();
        obj.checkParameterNotNull("userId");
        String userId = obj.getString("userId");
        SysUser sysUser = userService.selectUserById(Long.parseLong(userId));
        String result="";
        if (sysUser!=null){
            result = personRealnVerifyService.personRealnVerify(sysUser.getAccountId());
        }
        return result;
    }

    @ApiOperation(value = "E签宝个人认证成功回调接口（修改认证状态）",
                notes = "参数：{" +
                        "userId:'123'}" +
                        "错误：" +
                        "500 修改个人认证状态失败" +
                        "301 个人认证失败" +
                        "")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("/updateUserIsAuthentication")
    public Object updateUserIsAuthentication(){
        ParameterObject obj =  getParameterObject();
        String accountId = obj.getString("accountId");
        Boolean success = obj.getBoolean("success");
        if (success) {
            int result = userService.updateIsAuthentication("1", accountId);
            if (result > 0) {
                return AjaxResult.success().putKV("result", result);
            } else {
                return AjaxResult.error(500, "修改个人认证状态失败");
            }
        }else {
            return AjaxResult.error(301,"个人认证失败");
        }
    }


    @ApiOperation(value = "E签宝企业认证", notes = "参数：{'userId':'XXXXXXX'}" +
            "\n（userId：待认证e签宝用户id）")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params", paramType = "body")
    })
    @PostMapping("organRealVerify")
    public Object organRealVerify() {
        ParameterObject obj = getParameterObject();
        obj.checkParameterNotNull("userId");
        String userId = obj.getString("userId");
        SysUser sysUser = userService.selectUserById(Long.parseLong(userId));
        String result="";
        if (sysUser!=null){
            CustomersExt customersExt = customersExtService.selectCustomersExtById(sysUser.getSysUserExt().getOrgCode());
            if (customersExt!=null){
                result = organRealVerifyService.organRealVerify(sysUser.getAccountId(), customersExt.getOrgId());
            }
        }
        return result;
    }

    /*调用修改数据库企业认证状态*/
    @ApiOperation(value = "E签宝企业认证成功回调接口（修改认证状态）",
            notes = "参数：{" +
                    "userId:'123'}" +
                    "错误：" +
                    "500 修改企业认证状态失败" +
                    "301 企业认证失败" +
                    "")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("/updateCustomersIsAuthentication")
    public Object updateCustomersIsAuthentication(){
        ParameterObject obj =  getParameterObject();
        String accountId = obj.getString("accountId");
        Boolean success = obj.getBoolean("success");
        if (success) {
            int result = customersExtService.updateCustomersIsAuthentication("1", accountId);
            if (result > 0) {
                return AjaxResult.success().putKV("result", result);
            } else {
                return AjaxResult.error(500, "修改企业认证状态失败");
            }
        }else {
            return AjaxResult.error(301,"企业认证失败");
        }
    }

    /**
     * @descption: 个人注册
     * @param:
     * @return:
     * @auther: ZhangDing
     * @date: 2020-10-12 14:04
     */

    @ApiOperation(value = "E签宝个人注册返回认证接口",
            notes = "参数：{" +
                    "userId:'123'}" +
                    "错误：" +
                    "301  用户已经注册且认证" +
                    "500 注册失败" +
                    "")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @ApiPassToken
    @PostMapping("/createPersonalAccount")
    public Object createPersonalAccount(){
        ParameterObject obj =  getParameterObject();
        //判断参数
        obj.checkParameterNotNull("userId");
        String userId = obj.getString("userId");
//        SysUser user = obj.parseBean(SysUser.class);
        //根据用户loginName查询用户信息
        SysUser user = userService.selectUserById(Long.parseLong(userId));
        //判断是否注册
        if (user.getAccountId()!=null&&user.getAccountId()!=""){//已经注册
            //判断是否认证
            if ("1".equals(user.getIsAuthentication())){//已经认证
                return AjaxResult.error(301,"用户已经注册且认证");
            }else {//没有认证
                //获取认证路径
                String url = personRealnVerifyService.personRealnVerify(user.getAccountId());
                return AjaxResult.success("url",url);
            }
        }else {//没有注册
            //去注册
            SysUser euser = eSignService.createPersonalAccount(user);
            if (euser!=null) {
                //注册完以后获取认证路径
                String url = personRealnVerifyService.personRealnVerify(euser.getAccountId());
                return AjaxResult.success("url", url);
            }else {
                return AjaxResult.error(500,"注册失败");
            }
        }
    }

    /**
     * @descption: 公司注册
     * @param:
     * @return:
     * @auther: ZhangDing
     * @date: 2020-10-12 15:26
     */
    @ApiOperation(value = "E签宝企业注册返回认证接口",
            notes = "参数：{" +
                    "userId:'123',customersName:'XXX商贸公司',orgLegalIdNumber:'企业法定代表人证件号','orgLegalName':'企业法定代表人名称'}" +
                    "错误：" +
                    "301  企业已经注册且认证" +
                    "201  个人未注册" +
                    "500 注册失败" +
                    "")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @ResponseBody
    @PostMapping("/createThirdParty")
    public Object createThirdParty(){
        ParameterObject obj =  getParameterObject();
        obj.checkParameterNotNull("userId,customersName,orgLegalIdNumber,orgLegalName");
        Long userId = obj.getLong("userId");
        String customersName = obj.getString("customersName");
        String orgLegalIdNumber = obj.getString("orgLegalIdNumber");
        String orgLegalName = obj.getString("orgLegalName");
        SysUser user = userService.selectUserById(userId);
//        CustomersExt customersExt = obj.parseBean(CustomersExt.class);
        CustomersExt customersExt = customersExtService.selectCustomersExtById(user.getSysUserExt().getOrgCode());
        if (customersExt==null){
            customersExt = new CustomersExt();
            if (user.getAccountId()!=null&&user.getAccountId()!="") {
                customersExt.setCreator(user.getAccountId());
            }else {
                return AjaxResult.error(201,"个人未注册");
            }
            customersExt.setChainsCode(user.getSysUserExt().getOrgCode());
            customersExt.setCustomersName(customersName);
            customersExt.setOrgLegalidNumber(orgLegalIdNumber);
            customersExt.setOrgLegalName(orgLegalName);
        }
        //判断是否注册
        if (customersExt.getOrgId()!=null&&customersExt.getOrgId()!=""){//已经注册
            //判断是否认证
            if ("1".equals(customersExt.getIsAuthentication())){//已认证
                return AjaxResult.error(301,"企业已经注册且认证");
            }else {//未认证
                //获取认证路径
                String url = organRealVerifyService.organRealVerify(customersExt.getOrgId(),customersExt.getCreator());
                return AjaxResult.success("url",url);
            }
        }else {//未注册
            //去注册
            CustomersExt ecustomersExt = eSignService.createThirdParty(customersExt);
            if (ecustomersExt!=null) {
                //注册完以后获取认证路径
                String url = organRealVerifyService.organRealVerify(ecustomersExt.getOrgId(),ecustomersExt.getCreator());
                return AjaxResult.success("url", url);
            }else {
                return AjaxResult.error(500,"注册失败");
            }
        }
    }

//    /**
//     * @descption: e签宝修改个人信息
//     * @param:
//     * @return:
//     * @auther: ZhangDing
//     * @date: 2020-10-13 13:31
//     */
//    @ResponseBody
//    @PostMapping("/updatePersonalAccount")
//    public Object updatePersonalAccount(){
//        ParameterObject obj = getParameterObject();
//        obj.checkParameterNotNull("accountId");
//        SysUser user = obj.parseBean(SysUser.class);
//        return toAjax(eSignService.updatePersonalAccount(user));
//    }
//
//    /**
//     * @descption: e签宝修改公司信息
//     * @param:
//     * @return:
//     * @auther: ZhangDing
//     * @date: 2020-10-13 14:32
//     */
//    @ResponseBody
//    @PostMapping("/updateThirdParty")
//    public Object updateThirdParty(){
//        ParameterObject obj = getParameterObject();
//        obj.checkParameterNotNull("orgId");
//        CustomersExt customersExt = obj.parseBean(CustomersExt.class);
//        return toAjax(eSignService.updateThirdParty(customersExt));
//    }

}
