package com.dgtly.wxportal.controller;


import com.dgtly.common.annotation.ApiNoCheckSign;
import com.dgtly.common.annotation.ApiPassToken;
import com.dgtly.common.core.controller.ApiBaseController;
import com.dgtly.common.core.domain.AjaxResult;
import com.dgtly.common.core.domain.ParameterObject;
import com.dgtly.system.domain.CustomersExt;
import com.dgtly.system.domain.SysUser;
import com.dgtly.system.domain.SysUserExt;
import com.dgtly.system.service.ICustomersExtService;
import com.dgtly.system.service.ISysUserExtService;
import com.dgtly.system.service.ISysUserService;
import com.dgtly.wxportal.domain.WxBanner;
import com.dgtly.wxportal.domain.WxMagnet;
import com.dgtly.wxportal.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

@Api(tags = "微信门户相关接口")
@RestController
@RequestMapping("/wxportal")
@ApiPassToken
public class WxPortalController extends ApiBaseController {

    @Autowired
    private IWxMagnetService wxMagnetService;

    @Autowired
    private IWxBannerService wxBannerService;
    @Autowired
    private ESignService eSignService;
    @Autowired
    private ISysUserService userService;
    @Autowired
    private ISysUserExtService userExtService;
    @Autowired
    private ICustomersExtService customersExtService;
    @Autowired
    private IEsignPersonRealnVerifyService personRealnVerifyService;
    @Autowired
    private IEsignOrganRealVerifyService organRealVerifyService;

    @ApiOperation(value = "微信门户首页",notes = "参数：{userId:1}")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("/portalData")
    public Object getMagent(){
        ParameterObject obj =  getParameterObject();
        obj.checkParameterNotNull("userId");
        WxBanner wxBanner = new WxBanner();
        List<WxMagnet> wxMagnetList =  wxMagnetService.selectMagnetByUserId(obj.getString("userId"));
        List<WxBanner> wxBannerList = wxBannerService.selectWxBannerList(wxBanner);
        return AjaxResult.success().putKV("magnets",wxMagnetList).putKV("banners",wxBannerList);
    }



    @ApiOperation(value = "查询经销商人员列表", notes = "参数：{'userId':'XXXXXXX'}" +
            "\n（userId：用户id）")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params", paramType = "body")
    })
    @PostMapping("getDistributorList")
    public Object getDistributorList() {
        ParameterObject obj = getParameterObject();
        obj.checkParameterNotNull("userId");
        String userId = obj.getString("userId");
        SysUserExt userExt = userExtService.selectSysUserExtById(Long.parseLong(userId));
        if (userExt!=null){
            if ("1".equals(userExt.getIsCustomerManager())){
               List<SysUser> userList = userService.selectUserByOrgCode(userExt.getOrgCode());
                return AjaxResult.success(userList);
            }else{
                return AjaxResult.error("不是负责人");
            }
        }else{
            return AjaxResult.error("用户不存在");
        }
    }

    @ApiOperation(value = "设置/取消是否为收货人", notes = "参数：{'userId':'XXXXXXX','IsConsignee':'1'}" +
            "\n（userId：用户id" +
            "\n IsConsignee:是否收货人（0否1是））")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params", paramType = "body")
    })
    @PostMapping("updateOrgUser")
    public Object updateOrgUser() {
        ParameterObject obj = getParameterObject();
        obj.checkParameterNotNull("userId,IsConsignee");
        String userId = obj.getString("userId");
        String IsConsignee = obj.getString("IsConsignee");
        SysUser user = new SysUser();
        user.setUserId(Long.parseLong(userId));
        user.setIsConsignee(IsConsignee);
        int i = userService.updateUser(user);
        if (i>0){
            return AjaxResult.success("成功");
        }else {
            return AjaxResult.error("失败");
        }
    }
}
