package com.dgtly.wxportal.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.dgtly.system.domain.CustomersExt;
import com.dgtly.system.domain.SysUser;
import com.dgtly.system.service.ICustomersExtService;
import com.dgtly.system.service.ISysUserService;
import com.dgtly.wxportal.config.ESignConfig;
import com.dgtly.wxportal.service.ESignService;
import com.dgtly.wxportal.utils.ESign.ESignHttpUtil;
import com.dgtly.wxportal.utils.ESign.ESignUploadUtil;
import com.dgtly.wxportal.utils.ESign.ESignUrl;
import com.dgtly.wxportal.utils.pdf.PDFUtil;
import com.dgtly.wxportal.utils.pdf.Watermark;
import com.itextpdf.text.Document;
import com.itextpdf.text.PageSize;
import com.itextpdf.text.pdf.PdfWriter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.File;
import java.io.FileOutputStream;

/**
 * @author ZhangDing
 * @version 1.0
 * @descption: TODO
 * @company 神州数码通用软件（洛阳）有限公司
 * @copyright (c) 2019 LuoYang DGT Co'Ltd Inc. All rights reserved.
 * @date 2020-10-10 11:27
 * @since JDK1.8
 */
@Service
public class ESignServiceImpl implements ESignService {

    @Autowired
    private ESignHttpUtil eSignHttpUtil;
    @Autowired
    private ISysUserService userService;
    @Autowired
    private ICustomersExtService customersExtService;
    @Autowired
    private ESignConfig eSignConfig;

    @Override
    public String upload(String orderId) {
        //根据订单id生成pdf文件
        String filePath = creatPdf(orderId);
        String md5 = ESignUploadUtil.getStringContentMD5(filePath);
        String contentTtpe = "application/pdf";
        int fileLength = ESignUploadUtil.getFileSize(filePath);
        //根据文件获取上传路径
        JSONObject urlData =  getUpUrl(filePath,md5,contentTtpe,fileLength).getJSONObject("data");
        //文件id
        String fileId = urlData.getString("fileId");
        //文件上传路径
        String uploadUrl = urlData.getString("uploadUrl");
        //上传文件
        String res = eSignHttpUtil.upLoadFile(uploadUrl,filePath,md5,contentTtpe,fileLength);

        return fileId;
    }

    @Override
    public String verificationUser() {
        return null;
    }

    @Override
    public SysUser createPersonalAccount(SysUser user) {
        JSONObject json = new JSONObject();
        json.put("thirdPartyUserId",user.getLoginName());
        json.put("name",user.getUserName());
//        json.put("idType","CRED_PSN_CH_IDCARD");
//        json.put("idNumber",user.getIdNumber());
//        json.put("mobile",user.getPhonenumber());
//        json.put("email",user.getEmail());
        JSONObject resule = eSignHttpUtil.doPostGetJson(ESignUrl.CreatePersonalAccount,json);
        user.setAccountId(resule.getJSONObject("data").getString("accountId"));
        int isok = userService.insertPersonalAccount(user);
        if (isok>0){
            return user;
        }else {
            return null;
        }
    }

    @Override
    public CustomersExt createThirdParty(CustomersExt customersExt) {
        JSONObject json = new JSONObject();
        int isok = 1;
        json.put("thirdPartyUserId",customersExt.getChainsCode());
        json.put("creator",customersExt.getCreator());
        json.put("name",customersExt.getCustomersName());
//        json.put("idType","CRED_ORG_USCC");
//        json.put("idNumber",customersExt.getIdNumber());
        json.put("orgLegalIdNumber",customersExt.getOrgLegalidNumber());
        json.put("orgLegalName",customersExt.getOrgLegalName());
        JSONObject resule = eSignHttpUtil.doPostGetJson(ESignUrl.CreateThirdParty,json);
        customersExt.setOrgId(resule.getJSONObject("data").getString("orgId"));
        isok = customersExtService.insertCustomersExt(customersExt);
        if (isok>0){
            return customersExt;
        }else {
            return null;
        }
    }

    @Override
    public int updatePersonalAccount(SysUser user) {
        JSONObject json = new JSONObject();
        int isok = 0;
        JSONObject resule = null;
        if (user.getUserName()!=null) {
            json.put("name", user.getUserName());
        }
        if (user.getIdNumber()!=null) {
            json.put("idNumber", user.getIdNumber());
        }
        if (user.getPhonenumber()!=null) {
            json.put("mobile", user.getPhonenumber());
        }
        if (user.getEmail()!=null) {
            json.put("email", user.getEmail());
        }
        if (user.getAccountId()!=null) {
            resule  = eSignHttpUtil.doPutGetJson(ESignUrl.updatePersonalAccount, json, user.getAccountId());
            if (resule.getInteger("code")==0){
                isok = 1;
            }
        }

        return isok;
    }

    @Override
    public int updateThirdParty(CustomersExt customersExt) {
        JSONObject json = new JSONObject();
        int isok = 0;
        JSONObject resule = null;
        if (customersExt.getCustomersName()!=null) {
            json.put("name", customersExt.getCustomersName());
        }
        if (customersExt.getIdNumber()!=null) {
            json.put("idNumber", customersExt.getIdNumber());
        }
        if (customersExt.getOrgLegalidNumber()!=null) {
            json.put("orgLegalIdNumber", customersExt.getOrgLegalidNumber());
        }
        if (customersExt.getOrgLegalName()!=null) {
            json.put("orgLegalName", customersExt.getOrgLegalName());
        }
        if (customersExt.getOrgId()!=null) {
            resule  = eSignHttpUtil.doPutGetJson(ESignUrl.updateThirdParty, json, customersExt.getOrgId());
            if (resule.getInteger("code")==0){
                isok = 1;
            }
        }
        return isok;
    }

    /**
     * 创建收货单pdf文件
     * @param orderId
     * @return
     */
    private String creatPdf(String orderId){

        String fileUrl = "";
        try {
            // 1.新建document对象
            Document document = new Document(PageSize.A4);// 建立一个Document对象

            // 2.建立一个书写器(Writer)与document对象关联
            String uploadPath = eSignConfig.getFileUrl() ;
            File file = new File(uploadPath+File.separator+"PDFDemo.pdf");
            fileUrl = uploadPath+"/PDFDemo.pdf";
            file.createNewFile();

            PdfWriter writer = PdfWriter.getInstance(document, new FileOutputStream(file));
            writer.setPageEvent(new Watermark("我是水印"));// 水印
//                writer.setPageEvent(new MyHeaderFooter());// 页眉/页脚

            // 3.打开文档
            document.open();
            document.addTitle("    签   宝   租  铺  合  同 ");// 标题
            document.addAuthor("");// 作者
            document.addSubject("");// 主题
            document.addKeywords("");// 关键字
            document.addCreator("");// 创建者

            // 4.向文档中添加内容
            PDFUtil.generateEPDF(document,"11");

            // 5.关闭文档
            document.close();
        } catch (Exception e) {
            e.printStackTrace();
        }

        return fileUrl;
    }

    /**
     * 获取文件上传路径
     * @param filePath
     * @return
     */
    private JSONObject getUpUrl(String filePath,String contentMd5,String contentType,int fileLength){
        File file = new File(filePath);
        String fileName = file.getName();
        JSONObject json = new JSONObject();
        json.put("contentMd5", contentMd5);
        json.put("contentType",contentType);
        json.put("convert2Pdf",false);
        json.put("fileName",fileName);
        json.put("fileSize",fileLength);
        JSONObject result=  eSignHttpUtil.doPostGetJson(ESignUrl.uploadCreateFile,json);
        return result;
    }

}
